@@ -578,7 +578,7 @@ void makenewfontbutton()
 void togglefontmark(int fontval)
 {
    Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),fontfamily",
-		fonts[fontval].family, TCL_NAMESPACE_ONLY);
+		fonts[fontval].family, 0);
 }
 
 #endif /* TCL_WRAPPER */
@@ -643,7 +643,7 @@ void togglegrid(u_short type)
    /* value.								*/
 
    Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),gridstyle",
-	stylenames[type], TCL_NAMESPACE_ONLY);
+	stylenames[type], 0);
 }
 
 #endif /* TCL_WRAPPER */
@@ -892,8 +892,7 @@ void setcolormark(int colorval)
 	    break;
       objv[2] = Tcl_NewIntObj((int)i);
    }
-   Tcl_SetVar2Ex(xcinterp, "XCWinOps", "$XCOps(focus),colorval", objv[2],
-		TCL_NAMESPACE_ONLY);
+   Tcl_SetVar2Ex(xcinterp, "XCWinOps", "$XCOps(focus),colorval", objv[2], 0);
 
    XcTagCallback(xcinterp, 3, objv);
 }
@@ -931,14 +930,13 @@ void setallstylemarks(u_short styleval)
    else
       objv[2] = Tcl_NewStringObj("transparent", 11);
 
-   Tcl_SetVar2Ex(xcinterp, "XCWinOps", "$XCOps(focus),fillamount", objv[1],
-		TCL_NAMESPACE_ONLY);
+   Tcl_SetVar2Ex(xcinterp, "XCWinOps", "$XCOps(focus),fillamount", objv[1], 0);
    Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),opaque", (styleval & OPAQUE) ?
-		"true" : "false", TCL_NAMESPACE_ONLY);
+		"true" : "false", 0);
    Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),bboxtype", (styleval & BBOX) ?
-		"true" : "false", TCL_NAMESPACE_ONLY);
+		"true" : "false", 0);
    Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),polyclosed",
-		(styleval & UNCLOSED) ? "false" : "true", TCL_NAMESPACE_ONLY);
+		(styleval & UNCLOSED) ? "false" : "true", 0);
 
    switch (styleval & BORDERS) {
       case DASHED:
@@ -954,8 +952,7 @@ void setallstylemarks(u_short styleval)
 	 bptr = borders[SolidIdx];
 	 break;
    }
-   Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),linestyle", (char *)bptr,
-		TCL_NAMESPACE_ONLY);
+   Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),linestyle", (char *)bptr, 0);
 
    XcTagCallback(xcinterp, 3, objv);
 }
@@ -1156,16 +1153,16 @@ void togglestylemark(int styleval)
 {
    switch(styleval) {
       case 0: Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),fontstyle",
-		"normal", TCL_NAMESPACE_ONLY);
+		"normal", 0);
 	 break;
       case 1: Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),fontstyle",
-		"bold", TCL_NAMESPACE_ONLY);
+		"bold", 0);
 	 break;
       case 2: Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),fontstyle",
-		"italic", TCL_NAMESPACE_ONLY);
+		"italic", 0);
 	 break;
       case 3: Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),fontstyle",
-		"bolditalic", TCL_NAMESPACE_ONLY);
+		"bolditalic", 0);
 	 break;
    }
 }
@@ -1176,28 +1173,28 @@ void toggleencodingmark(int encodingval)
 {
    switch(encodingval) {
       case 0: Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),fontencoding",
-		"Standard", TCL_NAMESPACE_ONLY);
+		"Standard", 0);
 	 break;
       case 1: Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),fontencoding",
-		"special", TCL_NAMESPACE_ONLY);
+		"special", 0);
 	 break;
       case 2: Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),fontencoding",
-		"ISOLatin1", TCL_NAMESPACE_ONLY);
+		"ISOLatin1", 0);
 	 break;
       case 3: Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),fontencoding",
-		"ISOLatin2", TCL_NAMESPACE_ONLY);
+		"ISOLatin2", 0);
 	 break;
       case 4: Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),fontencoding",
-		"ISOLatin3", TCL_NAMESPACE_ONLY);
+		"ISOLatin3", 0);
 	 break;
       case 5: Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),fontencoding",
-		"ISOLatin4", TCL_NAMESPACE_ONLY);
+		"ISOLatin4", 0);
 	 break;
       case 6: Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),fontencoding",
-		"ISOLatin5", TCL_NAMESPACE_ONLY);
+		"ISOLatin5", 0);
 	 break;
       case 7: Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),fontencoding",
-		"ISOLatin6", TCL_NAMESPACE_ONLY);
+		"ISOLatin6", 0);
 	 break;
    }
 }
@@ -1208,38 +1205,38 @@ void togglejustmarks(int justvalue)
 {
    switch(justvalue & RLJUSTFIELD) {
       case NORMAL: Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),jhoriz",
-		"left", TCL_NAMESPACE_ONLY);
+		"left", 0);
 	 break;
       case NOTLEFT: Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),jhoriz",
-		"center", TCL_NAMESPACE_ONLY);
+		"center", 0);
 	 break;
       case RIGHT|NOTLEFT: Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),jhoriz",
-		"right", TCL_NAMESPACE_ONLY);
+		"right", 0);
 	 break;
    }
    switch(justvalue & TBJUSTFIELD) {
       case NORMAL: Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),jvert",
-		"bottom", TCL_NAMESPACE_ONLY);
+		"bottom", 0);
 	 break;
       case NOTBOTTOM: Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),jvert",
-		"middle", TCL_NAMESPACE_ONLY);
+		"middle", 0);
 	 break;
       case TOP|NOTBOTTOM: Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),jvert",
-		"top", TCL_NAMESPACE_ONLY);
+		"top", 0);
 	 break;
    }
 
    /* Flip Invariance property */
    Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),flipinvariant",
-		(justvalue & FLIPINV) ?  "true" : "false", TCL_NAMESPACE_ONLY);
+		(justvalue & FLIPINV) ?  "true" : "false", 0);
 
    /* LaTeX mode property */
    Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),latexmode",
-		(justvalue & LATEXLABEL) ?  "true" : "false", TCL_NAMESPACE_ONLY);
+		(justvalue & LATEXLABEL) ?  "true" : "false", 0);
      
    /* Pin visibility property */
    Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),pinvisible",
-		(justvalue & PINVISIBLE) ?  "true" : "false", TCL_NAMESPACE_ONLY);
+		(justvalue & PINVISIBLE) ?  "true" : "false", 0);
 }
 
 /*------------------------------------------------------*/
@@ -1543,23 +1540,23 @@ void boxedit(xcWidget w, pointertype value, caddr_t nulldata)
    switch (value) {
       case MANHATTAN:
 	 Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),polyedittype",
-		"manhattan", TCL_NAMESPACE_ONLY);
+		"manhattan", 0);
 	 break;
       case RHOMBOIDX:
 	 Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),polyedittype",
-		"rhomboidx", TCL_NAMESPACE_ONLY);
+		"rhomboidx", 0);
 	 break;
       case RHOMBOIDY:
 	 Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),polyedittype",
-		"rhomboidy", TCL_NAMESPACE_ONLY);
+		"rhomboidy", 0);
 	 break;
       case RHOMBOIDA:
 	 Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),polyedittype",
-		"rhomboida", TCL_NAMESPACE_ONLY);
+		"rhomboida", 0);
 	 break;
       case NORMAL:
 	 Tcl_SetVar2(xcinterp, "XCWinOps", "$XCOps(focus),polyedittype",
-		"normal", TCL_NAMESPACE_ONLY);
+		"normal", 0);
 	 break;
    }
 
