@@ -385,15 +385,14 @@ void setparammarks(genericptr thiselem)
 
    /* Reset all variables to false */
    for (i = 0; i < 14; i++)
-      Tcl_SetVar2(xcinterp, "XCOps", (char *)paramvars[i], "false", TCL_NAMESPACE_ONLY);
+      Tcl_SetVar2(xcinterp, "XCOps", (char *)paramvars[i], "false", 0);
 
    /* For each parameter declared, set the corresponding Tcl variable */
    if (thiselem != NULL) {
       for (epp = thiselem->passed; epp != NULL; epp = epp->next) {
 	 ops = match_param(topobject, epp->key);
 	 if (ops == NULL) continue;	/* error condition */
-         Tcl_SetVar2(xcinterp, "XCOps", (char *)paramvars[ops->which], "true",
-		TCL_NAMESPACE_ONLY);
+         Tcl_SetVar2(xcinterp, "XCOps", (char *)paramvars[ops->which], "true", 0);
       }
    }
 }
@@ -1207,9 +1206,11 @@ void copyparams(objinstptr destinst, objinstptr sourceinst)
 /* refobject.							*/
 /* The expression may have either a numeric or string result.	*/
 /* the proper "which" value is passed as an argument.		*/
+/*								*/
+/* Return FALSE if unsuccessful, TRUE otherwise			*/
 /*--------------------------------------------------------------*/
 
-void makeexprparam(objectptr refobject, char *key, char *value, int which)
+Boolean makeexprparam(objectptr refobject, char *key, char *value, int which)
 {
    oparamptr newops;
    char *newkey;
@@ -1221,7 +1222,8 @@ void makeexprparam(objectptr refobject, char *key, char *value, int which)
    /* Ensure that no two parameters have the same name! */
 
    if (check_param(refobject, newkey)) {
-      Wprintf("There is already a parameter with that key!");
+      Wprintf("There is already a parameter named %s!", newkey);
+      return FALSE;
    }
 
    newops = make_new_parameter(newkey);
@@ -1232,13 +1234,17 @@ void makeexprparam(objectptr refobject, char *key, char *value, int which)
    newops->parameter.expr = strdup(value);
    incr_changes(refobject);
    free(newkey);
+
+   return TRUE;
 }
 
 /*------------------------------------------------------------------*/
 /* Make an unreferenced numerical parameter in the object refobject */
+/*								    */
+/* Return FALSE if unsuccessful, TRUE otherwise.		    */
 /*------------------------------------------------------------------*/
 
-void makefloatparam(objectptr refobject, char *key, float value)
+Boolean makefloatparam(objectptr refobject, char *key, float value)
 {
    oparamptr newops;
    char *newkey;
@@ -1250,7 +1256,8 @@ void makefloatparam(objectptr refobject, char *key, float value)
    /* Ensure that no two parameters have the same name! */
 
    if (check_param(refobject, newkey)) {
-      Wprintf("There is already a parameter with that key!");
+      Wprintf("There is already a parameter named %s!", newkey);
+      return FALSE;
    }
 
    newops = make_new_parameter(key);
@@ -1261,13 +1268,16 @@ void makefloatparam(objectptr refobject, char *key, float value)
    newops->parameter.fvalue = value;
    incr_changes(refobject);
    free(newkey);
+
+   return TRUE;
 }
 
 /*----------------------------------------------------------------*/
 /* Make an unreferenced string parameter in the object refobject. */
+/* Return FALSE if unsuccessful, TRUE otherwise.		  */
 /*----------------------------------------------------------------*/
 
-void makestringparam(objectptr refobject, char *key, stringpart *strptr)
+Boolean makestringparam(objectptr refobject, char *key, stringpart *strptr)
 {
    oparamptr newops;
    char *newkey;
@@ -1279,7 +1289,8 @@ void makestringparam(objectptr refobject, char *key, stringpart *strptr)
    /* Ensure that no two parameters have the same name! */
 
    if (check_param(refobject, newkey)) {
-      Wprintf("There is already a parameter with that key!");
+      Wprintf("There is already a parameter named %s!", newkey);
+      return FALSE;
    }
 
    newops = make_new_parameter(newkey);
@@ -1290,6 +1301,8 @@ void makestringparam(objectptr refobject, char *key, stringpart *strptr)
    newops->parameter.string = strptr;
    incr_changes(refobject);
    free(newkey);
+
+   return TRUE;
 }
 
 /*--------------------------------------------------------------*/
