@@ -706,9 +706,9 @@ extern void free_element_param(genericptr, eparamptr);
 extern oparamptr make_new_parameter(char *);
 extern eparamptr make_new_eparam(char *);
 
-extern void makeexprparam(objectptr, char *, char *, int);
-extern void makefloatparam(objectptr, char *, float);
-extern void makestringparam(objectptr, char *, stringpart *);
+extern Boolean makeexprparam(objectptr, char *, char *, int);
+extern Boolean makefloatparam(objectptr, char *, float);
+extern Boolean makestringparam(objectptr, char *, stringpart *);
 extern void std_eparam(genericptr, char *);
 extern void indicateparams(genericptr);
 extern void setparammarks(genericptr);
