@@ -816,9 +816,11 @@ void clearselects_noundo()
 {
    if (areawin->selects > 0) {
       freeselects();
-      setallstylemarks(areawin->style);
-      setcolormark(areawin->color);
-      setdefaultfontmarks();
+      if (xobjs.suspend < 0) {
+         setallstylemarks(areawin->style);
+         setcolormark(areawin->color);
+         setdefaultfontmarks();
+      }
    }
 }
 
@@ -842,7 +844,8 @@ void clearselects()
 
 void unselect_all()
 {
-   draw_normal_selected(topobject, areawin->topinstance);
+   if (xobjs.suspend < 0)
+      draw_normal_selected(topobject, areawin->topinstance);
    clearselects();
 
 #ifdef TCL_WRAPPER
