@@ -153,10 +153,10 @@ stringpart *makesegment(stringpart **strhead, stringpart *before)
 	       char *key = lastptr->data.string;
 	       obs = find_param(areawin->topinstance, key);
 	       if (obs == NULL) {
-		  Wprintf("Error:  Bad parameter!");
-		  return NULL;
+		  Wprintf("Error:  Bad parameter \"%s\"!", key);
+	       } else {
+	          obs->parameter.string = newptr;	/* ?? */
 	       }
-	       obs->parameter.string = newptr;
 	    }
 	    else {
 	       lastptr->nextpart = newptr;
