@@ -21,8 +21,10 @@
 #include <stdarg.h>
 #include <string.h>
 
+#ifndef XC_WIN32
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
+#endif
 
 /*----------------------------------------------------------------------*/
 /* Local includes							*/
@@ -156,7 +158,7 @@ short *regen_selection(objinstptr thisinst, uselection *srec)
 	 k++;
       }
       else
-	 Fprintf(stderr, "Error: element 0x%x in select list but not object\n",
+	 Fprintf(stderr, "Error: element %p in select list but not object\n",
 		egen);
    } 
 
@@ -239,6 +241,7 @@ stringpart *get_original_string(labelptr thislab)
 	    return NULL;
       }
    }
+   return NULL;  /* yes, this can be reached, if thisrecord->next == NULL */
 }
 
 /*----------------------------------------------------------------------*/
@@ -586,7 +589,7 @@ short undo_one_action()
    thisrecord = xobjs.undostack;
    if (thisrecord == NULL) {
       Fprintf(stderr, "Nothing to undo!\n");
-      return;
+      return 0;
    }
 
    xobjs.undostack = thisrecord->next;
@@ -636,8 +639,9 @@ short undo_one_action()
 	    thisrecord->undodata = NULL;
 	    break;
 	 }
-	 else
-	    delete_one_element(thisrecord->thisinst, egen);
+	 else {
+	    delete_one_element(thisrecord->thisinst, egen); /* XXX egen is uninitialized! */
+	 }
 
 	 /* Put back all the parts */
 	 areawin->selects = thisobj->parts;
@@ -846,17 +850,17 @@ short undo_one_action()
 
       case XCF_Flip_X:
 	 position = *((XPoint *)thisrecord->undodata);
-	 elementflip(position.x, position.y);
+	 elementflip(&position);
 	 break;
 
       case XCF_Flip_Y:
 	 position = *((XPoint *)thisrecord->undodata);
-	 elementvflip(position.x, position.y);
+	 elementvflip(&position);
 	 break;
 
       case XCF_Rotate:
 	 position = *((XPoint *)thisrecord->undodata);
-	 elementrotate(-thisrecord->idata, position.x, position.y);
+	 elementrotate(-thisrecord->idata, &position);
 	 break;
 
       case XCF_Move:
@@ -924,7 +928,7 @@ short redo_one_action()
    thisrecord = xobjs.redostack;
    if (thisrecord == NULL) {
       Fprintf(stderr, "Nothing to redo!\n");
-      return;
+      return 0;
    }
    xobjs.undostack = thisrecord;
    xobjs.redostack = thisrecord->last;
@@ -1081,12 +1085,12 @@ short redo_one_action()
 
       case XCF_Flip_X:
 	 position = *((XPoint *)thisrecord->undodata);
-	 elementflip(position.x, position.y);
+	 elementflip(&position);
 	 break;
 
       case XCF_Flip_Y:
 	 position = *((XPoint *)thisrecord->undodata);
-	 elementvflip(position.x, position.y);
+	 elementvflip(&position);
 	 break;
 
       case XCF_ChangeStyle:
@@ -1160,7 +1164,7 @@ short redo_one_action()
 
       case XCF_Rotate:
 	 position = *((XPoint *)thisrecord->undodata);
-	 elementrotate(thisrecord->idata, position.x, position.y);
+	 elementrotate(thisrecord->idata, &position);
 	 break;
 
       case XCF_Move:
