@@ -771,7 +771,7 @@ typedef struct {
    float	width;
    short	radius; 	/* x-axis radius */
    short	yaxis;		/* y-axis radius */
-   float	angle1;
+   float	angle1;		/* endpoint angles, in degrees */
    float	angle2;
    XPoint	position;
    /* the following are for rendering only */
@@ -1415,6 +1415,7 @@ typedef struct {
    Boolean	filefilter;	/* Is the file list filtered? */
    Boolean	hold;		/* allow HOLD modifiers on buttons */
    u_short	new_changes;
+   char		suspend;	/* suspend graphics updates if TRUE */
    short	numlibs;
    short	pages;
    Pagedata	**pagelist;
